@@ -166,7 +166,7 @@ static void loadPhrases(const char *file) /*{{{*/
   /*}}}*/
 }
 /*}}}*/
-static void diction(const char *sent, size_t length, const char *file, int line) /*{{{*/
+static void diction(const char *sent, size_t length, const char *file, int line, int col, int endLine, int endCol) /*{{{*/
 {
   const char *lastout=sent;
   const char *s=sent;
@@ -203,8 +203,8 @@ static void diction(const char *sent, size_t length, const char *file, int line)
           ++hits;
           if (lastout==sent)
           {
-            if (quiet) printf("%d: ",line);
-            else printf("%s:%d: ",file,line);
+            if (quiet) printf("%d.%d-%d.%d: ",line,col,endLine,endCol);
+            else printf("%s:%d.%d-%d.%d: ",file,line,col,endLine,endCol);
           }
           while (lastout<s) putc(*lastout++,stdout);
           putc('[',stdout);
@@ -245,8 +245,8 @@ static void diction(const char *sent, size_t length, const char *file, int line)
           {
             if (lastout==sent)
             {
-              if (quiet) printf("%d: ",line);
-              else printf("%s:%d: ",file,line);
+              if (quiet) printf("%d-%d:%d-%d: ",line,endLine,col,endCol);
+              else printf("%s:%d-%d:%d-%d: ",file,line,endLine,col,endCol);
             }
             while (lastout<s) putc(*lastout++,stdout);
             putc('[',stdout);
